Aggregation
===========

.. currentmodule:: npap.aggregation

Aggregation strategies for combining node and edge properties.

Basic Strategies
----------------

.. automodule:: npap.aggregation.basic_strategies
   :members:
   :show-inheritance:
   :no-index:

Aggregation Modes
-----------------

.. automodule:: npap.aggregation.modes
   :members:
   :show-inheritance:
   :no-index:

Physical Strategies
-------------------

.. automodule:: npap.aggregation.physical_strategies
   :members:
   :show-inheritance:
   :no-index:
